@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: hjsmin
-version: 0.1.5.2
-id: hjsmin-0.1.5.2-1047ccfd810ad2476389611e596c4ae2
-key: hjsmi_FBBK0TbYJu3AK4W3F3fpqz
+version: 0.1.5.3
+id: hjsmin-0.1.5.3-408bbfe5511e989538833527e5c06f0a
+key: hjsmi_1zqeTuGvajw0vUqpC3dJ2B
 license: BSD3
 maintainer: Erik de Castro Lopo <erikd@mega-nerd.com>
 stability: unstable
@@ -19,10 +19,10 @@ exposed-modules:
     Text.Jasmine
 hidden-modules: Text.Jasmine.Pretty
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/hjsmin-0.1.5.2
-library-dirs: /usr/lib/ghc-7.10.3/site-local/hjsmin-0.1.5.2
-data-dir: /usr/share/arm-linux-ghc-7.10.3/hjsmin-0.1.5.2
-hs-libraries: HShjsmin-0.1.5.2-FBBK0TbYJu3AK4W3F3fpqz
+import-dirs: /usr/lib/ghc-7.10.3/site-local/hjsmin-0.1.5.3
+library-dirs: /usr/lib/ghc-7.10.3/site-local/hjsmin-0.1.5.3
+data-dir: /usr/share/arm-linux-ghc-7.10.3/hjsmin-0.1.5.3
+hs-libraries: HShjsmin-0.1.5.3-1zqeTuGvajw0vUqpC3dJ2B
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
